enchant();
window.onload = preloadAssets;

var game;
var scene;
var player;
var shots;
var enemies;
var score;
var scoreNum;
var life;
var addEnemyInterval = 1000;
var addEnemyIntervalMin = 300;


function preloadAssets(){
	game = new Game(960,320);
	game.preload(
		'images/chara1.gif',
		'images/icon0.gif',
		'sounds/jump.wav',
		'sounds/gameover.wav'
	);
	game.onload = init;
	game.start();
}


function init(){
	game.scale = 1;
	game.fps = 30;
	game.keybind(32,'space');
	scene = new Scene();
	scene.backgroundColor = "#000";
	game.pushScene(scene);

	shots = [];
	enemies = [];
	
	player = new Player(32,32);
	scene.addChild(player);
	
	score = new Label("SCORE:0");
	score.color = "#FC9";
	score.font = "normal normal 15px/1.0 monospace";
	scene.addChild(score);	
	scoreNum = 0;
	
	life = new Label("PLAYER:"+player.life);
	life.y = 17;
	life.color = "#FC9";
	life.font = "normal normal 15px/1.0 monospace";
	scene.addChild(life);
	
	main();
}


function main(){
	game.addEventListener(Event.ENTER_FRAME,entreFrame);
    game.addEventListener(Event.UP_BUTTON_DOWN,movePlayer);
    game.addEventListener(Event.DOWN_BUTTON_DOWN,movePlayer);
    game.addEventListener(Event.RIGHT_BUTTON_DOWN,movePlayer);
    game.addEventListener(Event.LEFT_BUTTON_DOWN,movePlayer);
    game.addEventListener('spacebuttondown',shoot);
    addEnemy();
}


function movePlayer(e){
	player.move(e.type);
}


function shoot(e){
	var s = new Shot(16,16);
	s.x = player.x + player.width;
	s.y = player.y + player.height / 2;
	scene.addChild(s);
	shots.push(s);
}


function entreFrame(e){
	player.enterFrame();
	var l = enemies.length;
	for(var i=0; i<l; i++){
		var deleteFlag = false;
		if(enemies[i].x + enemies[i].width < 0){
			deleteFlag = true;
		}else if(isHitShot(enemies[i])){
			deleteFlag = true;
			scoreNum += enemies[i].score;
			score.text = "SCORE:" + scoreNum;
		}else if(player.intersect(enemies[i])){	
			deleteFlag = true;
			player.life--;
			life.text = ("PLAYER:"+player.life);
			if(player.life<1){
				gameOver();
				return;
			}else{
				player.damage();
			}
		}
		if(deleteFlag){
			enemies[i].remove();
			scene.removeChild(enemies[i]);
			enemies.splice(i,1);
			i--;
			l--;
		}
	}	
}


function isHitShot(e){
	var l = shots.length;
	for(var i=0; i<l; i++){
		if(shots[i].intersect(e)){
			shots[i].remove();
			scene.removeChild(shots[i]);
			shots.splice(i,1);
			i--;
			l--;
			return true;
		}
	}
	return false;
}


function addEnemy(){
	var e = new Enemy(32,32);
	scene.addChild(e);
	enemies.push(e);
	addEnemyInterval -= 5;
	if(addEnemyInterval < addEnemyIntervalMin) addEnemyInterval = addEnemyIntervalMin;
	setTimeout(addEnemy,addEnemyInterval);
}


function gameOver(){
	game.pause();
	var label = new Label("GameOver");
	scene.addChild(label);
	label.color = "#FC9";
	label.x = game.width / 2 - 35;
	label.y = game.height / 2;
}


function error(mes){
	alert("Error：エラーが発生しました。\nメッセージ：\n" + mes);
}